==> compton-conf_0.14.1.orig.tar.xz: compton-conf-0.14.1/translations/compton-conf_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Impostazioni effetti speciali delle finestre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Ombra</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="67"/>
        <source>The blur radius for shadows</source>
        <translation>Ampiezza sfocatura per le ombre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="77"/>
        <source>The left offset for shadows</source>
        <translation>Estensione verso l&apos;alto delle ombre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="91"/>
        <source>The top offset for shadows</source>
        <translation>Estensione verso sinistra delle ombre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="105"/>
        <source>The translucency for shadows</source>
        <translation>Trasparenza delle ombre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="122"/>
        <source>Color of shadow</source>
        <translation>Colore dell&apos;ombra</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="57"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Correggi problemi con lo standard ARGB delle finestre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="60"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Ometti la parte della maschera di ombra dietro la finestra</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="50"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translatorcomment>drag&amp;drop windows?</translatorcomment>
        <translation>Nessuna ombra per finestre in spostamento</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="43"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Nessuna ombra per dock e pannelli</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="36"/>
        <source>Enable client-side shadows on windows</source>
        <translation>Abilita le ombre client-side alle finestre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="136"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Non disegnare ombre per tutte le finestre disegnate</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="143"/>
        <source>Crop shadows of maximized windows from extended displays</source>
        <translation>Ritaglia le ombre delle finestre massimizzate da schermi esterni</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="151"/>
        <source>Opacity</source>
        <translation>Trasparenza</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="160"/>
        <source>The opacity for menus</source>
        <translation>Trasparenza dei menu</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="167"/>
        <source>Default opacity of inactive windows</source>
        <translation>Trasparenza delle finestre inattive</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="174"/>
        <source>Default opacity for active windows</source>
        <translation>Trasparenza delle finestre attive</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="181"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Trasparenza delle barre del titolo e dei bordi</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="188"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>Intervallo della trasparenza del backend XRender (Aumentare il valore
potrebbe comportare un uso maggiore di risorse per il server grafico X)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="196"/>
        <source>Dim inactive windows</source>
        <translation>Offuscare finestre inattive</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="203"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Grado di offuscamento indipendente dall&apos;opacità</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="210"/>
        <source>Blur background of transparent windows</source>
        <translation>Sfumare lo sfondo delle finestre trasparenti</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="217"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Sfumare anche lo sfondo delle finestre trasparenti con bordo trasparente</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="224"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Grado di sfumatura indipendente dall&apos;opacità</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="292"/>
        <source>Fade</source>
        <translation>Dissolvenza</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="298"/>
        <source>Fade windows during opacity changes</source>
        <translation>Dissolvere le finestre durante il cambio di opacità</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="305"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Tempo tra i gradi della dissolvenza in millisecondi</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="312"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Cambio di opacità della dissolvenza in apertura</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="319"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Cambio di opacità della dissolvenza in chiusura</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="326"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Nessuna dissolvenza delle finestre in apertura e chiusura</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="369"/>
        <source>Other</source>
        <translation>Altro</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="381"/>
        <source>Rendering backend</source>
        <translation>Sistema di rendering</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="393"/>
        <source>X Render</source>
        <translation>Render X</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="400"/>
        <source>GLX (OpenGL)</source>
        <translation>GLX (OpenGL)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="416"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="209"/>
        <source>About ComptonConf</source>
        <translation>Informazioni su ComptonConf</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="210"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - Strumento di configurazione per Compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>

==> compton-conf_0.16.0.orig.tar.xz: compton-conf-0.16.0/translations/compton-conf_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Impostazioni effetti speciali delle finestre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Ombra</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="67"/>
        <source>The blur radius for shadows</source>
        <translation>Ampiezza sfocatura per le ombre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="77"/>
        <source>The left offset for shadows</source>
        <translation>Estensione verso l&apos;alto delle ombre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="91"/>
        <source>The top offset for shadows</source>
        <translation>Estensione verso sinistra delle ombre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="105"/>
        <source>The translucency for shadows</source>
        <translation>Trasparenza delle ombre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="122"/>
        <source>Color of shadow</source>
        <translation>Colore dell&apos;ombra</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="57"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Correggi problemi con lo standard ARGB delle finestre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="60"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Ometti la parte della maschera di ombra dietro la finestra</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="50"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translatorcomment>drag&amp;drop windows?</translatorcomment>
        <translation>Nessuna ombra per finestre in spostamento</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="43"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Nessuna ombra per dock e pannelli</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="36"/>
        <source>Enable client-side shadows on windows</source>
        <translation>Abilita le ombre client-side alle finestre</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="136"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Non disegnare ombre per tutte le finestre disegnate</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="143"/>
        <source>Crop shadows of maximized windows from extended displays</source>
        <translation>Ritaglia le ombre delle finestre massimizzate da schermi esterni</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="151"/>
        <source>Opacity</source>
        <translation>Opacità</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="160"/>
        <source>The opacity for menus</source>
        <translation>Opacità dei menu</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="167"/>
        <source>Default opacity of inactive windows</source>
        <translation>Opacità delle finestre inattive</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="174"/>
        <source>Default opacity for active windows</source>
        <translation>Opacità delle finestre attive</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="181"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Opacità delle barre del titolo e dei bordi</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="188"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>Intervallo della trasparenza del backend XRender (Aumentare il valore
potrebbe comportare un uso minore di risorse per il server grafico X)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="196"/>
        <source>Dim inactive windows</source>
        <translation>Offuscare finestre inattive</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="203"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Grado di offuscamento indipendente dall&apos;opacità</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="210"/>
        <source>Blur background of transparent windows</source>
        <translation>Sfuma lo sfondo delle finestre trasparenti</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="217"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Sfuma anche lo sfondo delle finestre trasparenti con bordo trasparente</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="224"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Grado di sfumatura indipendente dall&apos;opacità</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="292"/>
        <source>Fade</source>
        <translation>Dissolvenza</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="298"/>
        <source>Fade windows during opacity changes</source>
        <translation>Dissolvere le finestre durante il cambio di opacità</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="305"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Tempo tra i livelli di dissolvenza in millisecondi</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="312"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Cambio di opacità della dissolvenza in apertura</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="319"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Cambio di opacità della dissolvenza in chiusura</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="326"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Nessuna dissolvenza delle finestre in apertura e chiusura</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="369"/>
        <source>Other</source>
        <translation>Altro</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="381"/>
        <source>Rendering backend</source>
        <translation>Sistema di rendering</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="393"/>
        <source>X Render</source>
        <translation>Render X</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="400"/>
        <source>GLX (OpenGL)</source>
        <translation>GLX (OpenGL)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="416"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="209"/>
        <source>About ComptonConf</source>
        <translation>Informazioni su ComptonConf</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="210"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - Strumento di configurazione per Compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>
